@@ -198,11 +198,11 @@ def wp_jackknife(sample1, randoms, rp_bins, pi_max, Nsub=[5, 5, 5],
 
     Create some 'randoms' in the same way:
 
-    >>> Nran = Npts*500
+    >>> Nran = Npts*5
     >>> xran = np.random.uniform(0, Lbox, Nran)
     >>> yran = np.random.uniform(0, Lbox, Nran)
     >>> zran = np.random.uniform(0, Lbox, Nran)
-    >>> randoms = np.vstack((x,y,z)).T
+    >>> randoms = np.vstack((xran,yran,zran)).T
 
     Calculate the jackknife covariance matrix by dividing the simulation box
     into 3 samples per dimension (for a total of 3^3 total jackknife samples):
@@ -319,10 +319,10 @@ def wp_jackknife(sample1, randoms, rp_bins, pi_max, Nsub=[5, 5, 5],
 
     # calculate the covariance matrix
     if (do_auto is True):
-        xi_11_cov = np.matrix(np.cov(xi_11_sub.T, bias=True))*(N_sub_vol-1)
-        xi_22_cov = np.matrix(np.cov(xi_22_sub.T, bias=True))*(N_sub_vol-1)
+        xi_11_cov = np.array(np.cov(xi_11_sub.T, bias=True))*(N_sub_vol-1)
+        xi_22_cov = np.array(np.cov(xi_22_sub.T, bias=True))*(N_sub_vol-1)
     if (do_cross is True):
-        xi_12_cov = np.matrix(np.cov(xi_12_sub.T, bias=True))*(N_sub_vol-1)
+        xi_12_cov = np.array(np.cov(xi_12_sub.T, bias=True))*(N_sub_vol-1)
 
     if _sample1_is_sample2:
         return xi_11_full, xi_11_cov
